@@ -4,9 +4,6 @@ import networkx as nx
 import numpy as np
 
 
-def modularity(partition, graph):
-    return nx.algorithms.community.modularity(graph.get_nx_graph(), partition)
-
 
 def find_best_partition(graph):
     if graph.directed():
