@@ -13,7 +13,7 @@ def powerlaw(n, alp, st=1, ac=0.3, status=None, status_back=False):
     else:
         alp_ = status
     while True:
-        rs = np.trunc(nx.utils.powerlaw_sequence(n, alp_+1)) - 1 + st
+        rs = np.trunc(nx.utils.powerlaw_sequence(n, alp_ + 1)) - 1 + st
         alp2 = boot_estimate(
             HillEstimator,
             rs,
@@ -22,7 +22,7 @@ def powerlaw(n, alp, st=1, ac=0.3, status=None, status_back=False):
             100
         )
 
-        if np.abs(alp2[0]-alp) <= ac:
+        if np.abs(alp2[0] - alp) <= ac:
             break
         else:
             if alp2[0] > alp:
@@ -40,12 +40,12 @@ def powerlaw_degree(n, alpha, beta, ac=0.3, status=(None, None), rep=5):
 
     zv = np.sum(np.subtract(out_d, ind_d))
     for _ in np.arange(rep):
-        out_d_, out_status = powerlaw(n, beta, int((beta > alpha))*(np.abs(zv)//n) + 1, ac=ac,
+        out_d_, out_status = powerlaw(n, beta, int((beta > alpha)) * (np.abs(zv) // n) + 1, ac=ac,
                                       status_back=True, status=out_status)
         if np.abs(np.sum(np.subtract(out_d_, ind_d))) < np.abs(zv):
             out_d = out_d_
             zv = np.sum(np.subtract(out_d, ind_d))
-        ind_d_, in_status = powerlaw(n, alpha, int((beta < alpha))*(np.abs(zv)//n) + 1, ac=ac,
+        ind_d_, in_status = powerlaw(n, alpha, int((beta < alpha)) * (np.abs(zv) // n) + 1, ac=ac,
                                      status_back=True, status=in_status)
         if np.abs(np.sum(np.subtract(out_d, ind_d_))) < np.abs(zv):
             ind_d = ind_d_
@@ -58,7 +58,7 @@ def powerlaw_degree(n, alpha, beta, ac=0.3, status=(None, None), rep=5):
 
 class Creator:
     @staticmethod
-    def tbt(nm, alpha, beta, prm=0.3):
+    def tbt(nm, alpha, beta, prm=0.3, nam=""):
         k = 1 - min([0.5, 1 - alpha ** -1, 1 - beta ** -1]) / 2
         zv = nm
 
@@ -75,20 +75,27 @@ class Creator:
             else:
                 out_d[i] = out_d[i] + 1
 
+        ps = nx.directed_configuration_model(ind_d.astype("int"), out_d.astype("int"))
         gr = SGraph(nx.MultiDiGraph())
-        gr.add_nodes(np.arange(nm))
+        count = 0
+        for edge in ps.edges:
+            gr.add_edge(edge[0], edge[1], key="tbt-"+nam + str(count))
+            count += 1
+        #gr.add_nodes(np.arange(nm))
+        #
+        #count = 0
+        #for i in np.arange(nm):
+        #    if ind_d[i] == 0:
+        #        continue
+        #    i_s = np.setdiff1d(np.arange(nm), i)
+        #    np.random.shuffle(i_s)
 
-        for i in np.arange(nm):
-            if ind_d[i] == 0:
-                continue
-            i_s = np.setdiff1d(np.arange(nm), i)
-            np.random.shuffle(i_s)
-
-            for j in i_s:
-                if out_d[int(j)] > gr.count_out_degree(j):
-                    gr.add_edge(j, i)
-                if ind_d[int(j)] > gr.count_in_degree(j):
-                    gr.add_edge(i, j)
+        #    for j in i_s:
+        #        if out_d[int(j)] > gr.count_out_degree(j):
+        #            gr.add_edge(j, i, key="tbt-"+nam + str(count))
+        #        if ind_d[int(j)] > gr.count_in_degree(j):
+        #            gr.add_edge(i, j, key="tbt-"+nam + str(count))
+        #        count += 1
 
         return gr
 
@@ -220,8 +227,8 @@ class Creator:
 
     @staticmethod
     def load(path, typ=nx.Graph):
-        return SGraph(typ(nx.read_graphml(path)))
+        return SGraph(typ(nx.read_graphml(path, force_multigraph=((typ == nx.MultiDiGraph) or (typ == nx.MultiGraph)))))
 
     @staticmethod
     def load_adj(path, typ=nx.Graph):
-        return SGraph(typ(nx.read_adjlist(path)))
+        return SGraph(typ(nx.read_adjlist(path, force_multigraph=((typ == nx.MultiDiGraph) or (typ == nx.MultiGraph)))))
