@@ -72,6 +72,7 @@ class CustomCreator:
                 prts = graph.get_attributes("prt")
                 id_ns = np.arange(nodes.size)
                 np.random.shuffle(id_ns)
+                count = 0
                 for i in id_ns:
                     if dg_in[i] != 0:
                         indx = np.arange(nodes.size)[(prts != prts[i]) & (dg_out > 0)]
@@ -82,8 +83,9 @@ class CustomCreator:
 
                         for add in adds:
                             if dg_out[add] > 0:
-                                graph.add_edge(nodes[i], nodes[add])
+                                graph.add_edge(nodes[i], nodes[add], key="spl-" + str(count))
                                 dg_out[add] -= 1
+                                count += 1
                         dg_in[i] = 0
 
                 nx.write_graphml(graph.get_nx_graph(), path + "custom_" + str(prt_) + "_" + str(_) + ".graphml")
