@@ -2,7 +2,9 @@ import numpy as np
 
 
 def first_order(graph, basis, typ="in"):
-    clss = [[]]*(len(basis)+1)
+    clss = []
+    for _ in np.arange(len(basis)+1):
+        clss.append([])
 
     for node in graph.get_ids():
         fnd = False
@@ -25,7 +27,10 @@ def first_order(graph, basis, typ="in"):
                     clss[i].append(node)
                     break
 
-        if fnd:
+            if fnd:
+                break
+
+        if fnd is False:
             clss[-1].append(node)
     return clss
 
